==> openvas-scanner-debug-23.13.1-1-x86_64.pkg.tar.zst: usr/src/debug/openvas-scanner/openvas-scanner-23.13.1/nasl/nasl_grammar.tab.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_NASL_NASL_GRAMMAR_TAB_H_INCLUDED
# define YY_NASL_NASL_GRAMMAR_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 1
#endif
#if YYDEBUG
extern int nasldebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    IF = 258,                      /* IF  */
    ELSE = 259,                    /* ELSE  */
    EQ = 260,                      /* EQ  */
    NEQ = 261,                     /* NEQ  */
    SUPEQ = 262,                   /* SUPEQ  */
    INFEQ = 263,                   /* INFEQ  */
    OR = 264,                      /* OR  */
    AND = 265,                     /* AND  */
    MATCH = 266,                   /* MATCH  */
    NOMATCH = 267,                 /* NOMATCH  */
    REP = 268,                     /* REP  */
    FOR = 269,                     /* FOR  */
    REPEAT = 270,                  /* REPEAT  */
    UNTIL = 271,                   /* UNTIL  */
    FOREACH = 272,                 /* FOREACH  */
    WHILE = 273,                   /* WHILE  */
    BREAK = 274,                   /* BREAK  */
    CONTINUE = 275,                /* CONTINUE  */
    FUNCTION = 276,                /* FUNCTION  */
    RETURN = 277,                  /* RETURN  */
    INCLUDE = 278,                 /* INCLUDE  */
    LOCAL = 279,                   /* LOCAL  */
    GLOBAL = 280,                  /* GLOBAL  */
    PLUS_PLUS = 281,               /* PLUS_PLUS  */
    MINUS_MINUS = 282,             /* MINUS_MINUS  */
    L_SHIFT = 283,                 /* L_SHIFT  */
    R_SHIFT = 284,                 /* R_SHIFT  */
    R_USHIFT = 285,                /* R_USHIFT  */
    EXPO = 286,                    /* EXPO  */
    PLUS_EQ = 287,                 /* PLUS_EQ  */
    MINUS_EQ = 288,                /* MINUS_EQ  */
    MULT_EQ = 289,                 /* MULT_EQ  */
    DIV_EQ = 290,                  /* DIV_EQ  */
    MODULO_EQ = 291,               /* MODULO_EQ  */
    L_SHIFT_EQ = 292,              /* L_SHIFT_EQ  */
    R_SHIFT_EQ = 293,              /* R_SHIFT_EQ  */
    R_USHIFT_EQ = 294,             /* R_USHIFT_EQ  */
    RE_MATCH = 295,                /* RE_MATCH  */
    RE_NOMATCH = 296,              /* RE_NOMATCH  */
    ARROW = 297,                   /* ARROW  */
    IDENT = 298,                   /* IDENT  */
    STRING1 = 299,                 /* STRING1  */
    STRING2 = 300,                 /* STRING2  */
    INTEGER = 301,                 /* INTEGER  */
    NOT = 302,                     /* NOT  */
    UMINUS = 303,                  /* UMINUS  */
    BIT_NOT = 304                  /* BIT_NOT  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 57 "/build/openvas-scanner/src/openvas-scanner-23.13.1/nasl/nasl_grammar.y"

  long int       num;
  char		*str;
  struct asciiz {
    char	*val;
    int		len;
  } data;
  tree_cell	*node;

#line 123 "nasl_grammar.tab.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif




int naslparse (naslctxt * parm, int * err_c);


#endif /* !YY_NASL_NASL_GRAMMAR_TAB_H_INCLUDED  */

==> openvas-scanner-debug-23.29.0-1-x86_64.pkg.tar.zst: usr/src/debug/openvas-scanner/openvas-scanner-23.29.0/nasl/nasl_grammar.tab.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_NASL_NASL_GRAMMAR_TAB_H_INCLUDED
# define YY_NASL_NASL_GRAMMAR_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 1
#endif
#if YYDEBUG
extern int nasldebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    IF = 258,                      /* IF  */
    ELSE = 259,                    /* ELSE  */
    EQ = 260,                      /* EQ  */
    NEQ = 261,                     /* NEQ  */
    SUPEQ = 262,                   /* SUPEQ  */
    INFEQ = 263,                   /* INFEQ  */
    OR = 264,                      /* OR  */
    AND = 265,                     /* AND  */
    MATCH = 266,                   /* MATCH  */
    NOMATCH = 267,                 /* NOMATCH  */
    REP = 268,                     /* REP  */
    FOR = 269,                     /* FOR  */
    REPEAT = 270,                  /* REPEAT  */
    UNTIL = 271,                   /* UNTIL  */
    FOREACH = 272,                 /* FOREACH  */
    WHILE = 273,                   /* WHILE  */
    BREAK = 274,                   /* BREAK  */
    CONTINUE = 275,                /* CONTINUE  */
    FUNCTION = 276,                /* FUNCTION  */
    RETURN = 277,                  /* RETURN  */
    INCLUDE = 278,                 /* INCLUDE  */
    LOCAL = 279,                   /* LOCAL  */
    GLOBAL = 280,                  /* GLOBAL  */
    PLUS_PLUS = 281,               /* PLUS_PLUS  */
    MINUS_MINUS = 282,             /* MINUS_MINUS  */
    L_SHIFT = 283,                 /* L_SHIFT  */
    R_SHIFT = 284,                 /* R_SHIFT  */
    R_USHIFT = 285,                /* R_USHIFT  */
    EXPO = 286,                    /* EXPO  */
    PLUS_EQ = 287,                 /* PLUS_EQ  */
    MINUS_EQ = 288,                /* MINUS_EQ  */
    MULT_EQ = 289,                 /* MULT_EQ  */
    DIV_EQ = 290,                  /* DIV_EQ  */
    MODULO_EQ = 291,               /* MODULO_EQ  */
    L_SHIFT_EQ = 292,              /* L_SHIFT_EQ  */
    R_SHIFT_EQ = 293,              /* R_SHIFT_EQ  */
    R_USHIFT_EQ = 294,             /* R_USHIFT_EQ  */
    RE_MATCH = 295,                /* RE_MATCH  */
    RE_NOMATCH = 296,              /* RE_NOMATCH  */
    ARROW = 297,                   /* ARROW  */
    IDENT = 298,                   /* IDENT  */
    STRING1 = 299,                 /* STRING1  */
    STRING2 = 300,                 /* STRING2  */
    INTEGER = 301,                 /* INTEGER  */
    NOT = 302,                     /* NOT  */
    UMINUS = 303,                  /* UMINUS  */
    BIT_NOT = 304                  /* BIT_NOT  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 57 "/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/OpenVAS/openvas-scanner/src/openvas-scanner-23.29.0/nasl/nasl_grammar.y"

  long int       num;
  char		*str;
  struct asciiz {
    char	*val;
    int		len;
  } data;
  tree_cell	*node;

#line 123 "nasl_grammar.tab.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif




int naslparse (naslctxt * parm, int * err_c);


#endif /* !YY_NASL_NASL_GRAMMAR_TAB_H_INCLUDED  */
